@@ -4,7 +4,10 @@ kcv.rda <-
            parallel = FALSE) 
 {
     kcvcheck(y = y, nfolds = nfolds, parallel = parallel, foldid = foldid)
-    if (is.null(prior)) {prior <- (table(y) / length(y))}
+    if (is.null(prior)) {
+      frac <- table(y) / length(y)
+      prior <- rep(1 / length(frac), length(frac))
+    }
     grid.row <- nrow(rda.grid)
     cv.rda <- matrix(rep(0, grid.row * nfolds), ncol = nfolds)
     if (parallel == TRUE) {
